@@ -14,7 +14,7 @@ keyMap = {
 	"up": 25,
 	"right": 26,
 	"alt": 31,
-	"x": 32,
+	"f10": 32,
 	"f7": 33,
 	"down": 34,
 	"a": 41,
